@@ -20,20 +20,13 @@ from django.views.generic import View
 from boundaries import kml
 from boundaries.models import app_settings
 
+
 class RawJSONResponse(object):
     """APIView subclasses can return these if they have
     already-serialized JSON to return"""
     def __init__(self, content):
         self.content = content
 
-throttle = None
-if getattr(app_settings, 'THROTTLE', ''):
-    def _import_from_string(val):
-        parts = val.split('.')
-        module_path, class_name = '.'.join(parts[:-1]), parts[-1]
-        module = importlib.import_module(module_path)
-        return getattr(module, class_name)
-    throttle = _import_from_string(app_settings.THROTTLE)()
 
 class BadRequest(Exception):
     pass
@@ -47,15 +40,6 @@ class APIView(View):
     content_type = 'application/json; charset=utf-8'
 
     def dispatch(self, request, *args, **kwargs):
-        if throttle is not None:
-            if not throttle.allow_request(request, self):
-                msg = ("You've exceeded the request limit."
-                    " Try again in %d seconds." % throttle.wait() +
-                    " Contact us if you need to be able to exceed the default limit.")
-                return HttpResponse(msg,
-                    content_type='text/plain',
-                    status=503)
-
         try:
             result = super(APIView, self).dispatch(request, *args, **kwargs)
         except BadRequest as e:
