@@ -1,7 +1,8 @@
+from __future__ import unicode_literals
 from xml.sax.saxutils import escape
 
 def generate_placemark(name, geom):
-    return u"<Placemark><name>%s</name>%s</Placemark>" %(
+    return "<Placemark><name>%s</name>%s</Placemark>" %(
         escape(name),
         geom.kml
     )
@@ -12,4 +13,4 @@ def generate_kml_document(placemarks):
 <Document>
 %s
 </Document>
-</kml>""" % u"\n".join(placemarks)
+</kml>""" % "\n".join(placemarks)
