@@ -47,7 +47,7 @@ class Command(BaseCommand):
     )
 
     def get_version(self):
-        return '0.3.2'
+        return '0.4.0'
 
     def handle(self, *args, **options):
         if settings.DEBUG:
@@ -130,6 +130,8 @@ class Command(BaseCommand):
             source_url=config.get('source_url', ''),
             notes=config.get('notes', ''),
             licence_url=config.get('licence_url', ''),
+            start_date=config.get('start_date', None),
+            end_date=config.get('end_date', None),
             # Load from either the 'extra' or 'metadata' fields
             extra=config.get('extra', config.get('metadata', None))
         )
@@ -213,7 +215,7 @@ class Command(BaseCommand):
 
             external_id = str(config['id_func'](feature))
             feature_name = config['name_func'](feature)
-            feature_slug = slugify(config['slug_func'](feature).replace('—', '-'))
+            feature_slug = slugify(str(config['slug_func'](feature)).replace('—', '-'))  # m-dash
 
             log.info('%s...' % feature_slug)
 
