@@ -23,31 +23,6 @@ class MyAppConf(AppConf):
     # The value for the Access-Control-Allow-Origin header
     ALLOW_ORIGIN = '*'
 
-    # To enable the throttle, in the main Django settings.py, set
-    # BOUNDARIES_THROTTLE = 'boundaries.throttle.AnonRateThrottle'
-    THROTTLE = ''
-
-    # The HTTP header containing the IP the request is coming from.
-    # If you're behind a reverse proxy, you might want e.g.
-    # BOUNDARIES_THROTTLE_IP_HEADER = 'X_REAL_IP'
-    THROTTLE_IP_HEADER = 'REMOTE_ADDR'
-
-    # Rates are in the form (number of requests, number of seconds)
-    DEFAULT_THROTTLE_RATES = {
-        'anon': (90, 90)  # Throttle after 90 requests in 90 seconds.
-    }
-
-    # Any IP addresses here won't be throttled
-    THROTTLE_IP_WHITELIST = set()
-
-    # If an API key in THROTTLE_APIKEY_LIST is provided,
-    # via the HEADER header or PARAM GET parameter,
-    # the request won't be throttled
-    THROTTLE_APIKEY_HEADER = 'X-Represent-Key'
-    THROTTLE_APIKEY_PARAM = 'key'
-    THROTTLE_APIKEY_LIST = set()
-
-    THROTTLE_LOG = False  # On True, throws a warning whenever someone's throttled
 
 app_settings = MyAppConf()
 
@@ -76,6 +51,10 @@ class BoundarySet(models.Model):
         help_text='The URL to the text of the licence this data is distributed under')
     extent = JSONField(blank=True, null=True,
         help_text='The bounding box of the boundaries in EPSG:4326 projection, as a list such as [xmin, ymin, xmax, ymax].')
+    start_date = models.DateField(
+        help_text='The date on which this set of boundaries went into effect.', null=True)
+    end_date = models.DateField(
+        help_text='The date on which this set of boundaries was superceded.', null=True)
     extra = JSONField(blank=True, null=True,
         help_text="Any other nonstandard metadata provided when creating this boundary set.")
 
@@ -94,7 +73,7 @@ class BoundarySet(models.Model):
     name_plural = property(lambda s: s.name)
     name_singular = property(lambda s: s.singular)
 
-    api_fields = ('name_plural', 'name_singular', 'authority', 'domain', 'source_url', 'notes', 'licence_url', 'last_updated', 'extent', 'extra')
+    api_fields = ('name_plural', 'name_singular', 'authority', 'domain', 'source_url', 'notes', 'licence_url', 'last_updated', 'extent', 'extra', 'start_date', 'end_date')
     api_fields_doc_from = { 'name_plural': 'name', 'name_singular': 'singular' }
 
     def as_dict(self):
